'-----------------------------------------------
'  clsSQLStringsAccess     VB2005
'  Klasse zur Erstellung von SQL Anweisungen fr
'  Select, Insert, Update
'
'  Autor:      peter.k.sauer@web.de
'  created:    22.02.2008
'-----------------------------------------------


Public Class clsSQLStringsAccess

   Private colFieldNames As New List(Of String)
   Private colFieldValues As New List(Of String)

   ''' <summary>
   ''' erstellt neue Field- Value-Collection fr Insert, Update
   ''' </summary>
   ''' <remarks></remarks>
   Public Sub FldListNew()

      colFieldNames.Clear()
      colFieldValues.Clear()
   End Sub

   ''' <summary>
   ''' fgt Field-Name und -Value zur Collection hinzu
   ''' </summary>
   ''' <param name="FieldName">Name DB Feld</param>
   ''' <param name="FieldValue">Feld Value</param>
   Public Sub FldListAdd(ByVal FieldName As String, ByVal FieldValue As String)

      colFieldNames.Add(FieldName)
      colFieldValues.Add(FieldValue)
   End Sub

   ''' <summary>
   ''' Field- und ValueList drucken
   ''' </summary>
   ''' <remarks></remarks>
   Public Sub FldListDebugPrint()

      Debug.Print("colFieldNames: colFieldValues")
      For i As Integer = 0 To colFieldNames.Count - 1
         Debug.Print(colFieldNames(i).ToString & ": " & colFieldValues(i).ToString)
      Next
   End Sub

   ''' <summary>
   ''' liefert einen String fr SQL Insert
   ''' </summary>
   ''' <param name="TableName">Tabelle fr Insert</param>
   Public ReadOnly Property GetInsert(ByVal TableName As String) As String
      Get
         Dim s As New System.Text.StringBuilder
         s.Append("Insert Into " & TableName & " (")
         Dim i As Integer
         For i = 0 To colFieldNames.Count - 1
            s.Append("[" & colFieldNames(i).ToString & "], ")
         Next
         s.Remove(s.ToString.Length - 2, 2)
         s.Append(") Values (")
         For i = 0 To colFieldValues.Count - 1
            s.Append(colFieldValues(i).ToString & ", ")
         Next
         s.Remove(s.ToString.Length - 2, 2)
         s.Append(") ")
         Return s.ToString
      End Get
   End Property

   ''' <summary>
   ''' liefert einen String fr Update
   ''' </summary>
   ''' <param name="TableName">Tabelle Update</param>
   ''' <param name="sWhere">optional, Beispiel: ID = 4711</param>
   Public ReadOnly Property GetUpdate(ByVal TableName As String, _
                                      Optional ByVal sWhere As String = Nothing) As String

      Get
         Dim s As New System.Text.StringBuilder
         s.Append("Update " & TableName & " Set ")
         For i As Integer = 0 To colFieldNames.Count - 1
            s.AppendFormat("[{0}] = {1}, ", colFieldNames(i).ToString, _
                                              colFieldValues(i).ToString)
         Next
         s.Remove(s.ToString.Length - 2, 2)
         s.Append(" ")
         If sWhere <> Nothing Then
            s.AppendFormat("Where {0}", sWhere)
         End If
         Return s.ToString
      End Get
   End Property

   ''' <summary>
   ''' liefert einen SQL gerechten String fr einen String
   ''' </summary>
   ''' <param name="sString">zu darstellender String</param>
   Public ReadOnly Property strStr(ByVal sString As String) As String

      Get
         If sString = Nothing Then
            Return "Null"
         End If
         sString = sString.Replace("'", "''")
         'sString = sString.Replace("""", """""")
         Return "'" & sString & "'"
      End Get
   End Property

   ''' <summary>
   ''' liefert einen SQL gerechten String fr ein Datum
   ''' </summary>
   ''' <param name="Datum">dazustellendes Datum</param>
   ''' <value></value>
   Public ReadOnly Property strDate(ByVal Datum As Date) As String
      Get
         If Datum = Nothing Then
            Return "Null"
         End If
         Dim s As String = Datum.ToString("\#MM\/dd\/yyyy\#")
         Return s
      End Get
   End Property

   ''' <summary>
   ''' liefert einen SQL gerechten String fr ein Datum
   ''' </summary>
   ''' <param name="Datum">dazustellendes Datum</param>
   Public ReadOnly Property strDate(ByVal Datum As String) As String
      Get
         If Datum = Nothing Then
            Return "Null"
         End If
         Dim d As Date = Date.Parse(Datum)
         Dim s As String = d.ToString("\#MM\/dd\/yyyy\#")
         Return s
      End Get
   End Property

   ''' <summary>
   ''' liefert einen SQL gerechten String fr Datum + Uhrzeit
   ''' </summary>
   ''' <param name="Datum">abzubildendes Datum</param>
   Public ReadOnly Property strDateTime(ByVal Datum As Date) As String
      Get
         If Datum = Nothing Then
            Return "Null"
         End If
         Dim s As String = Datum.ToString("\#MM\/dd\/yyyy HH:mm:ss\#")
         Return s
      End Get
   End Property

   ''' <summary>
   ''' liefert einen SQL gerechten String fr Datum + Uhrzeit
   ''' </summary>
   ''' <param name="Datum">abzubildendes Datum</param>
   Public ReadOnly Property strDateTime(ByVal Datum As String) As String
      Get
         If Datum = Nothing Then
            Return "Null"
         End If
         Dim d As Date = Date.Parse(Datum)
         Dim s As String = d.ToString("\#MM\/dd\/yyyy HH:mm:ss\#")
         Return s
      End Get
   End Property

   ''' <summary>
   ''' liefert ein Datum mit der Uhrzeit 23:59:59 fr Between
   ''' </summary>
   ''' <param name="Datum"></param>
   ''' <value></value>
   ''' <returns></returns>
   ''' <remarks></remarks>
   Public ReadOnly Property strDateMidNight(ByVal Datum As Date) As String
      Get
         Datum = Convert.ToDateTime(Datum.ToString("dd.MM.yyyy") & " 23:59:59")
         Return Datum.ToString("\#\/MM\/dd\/yyyy HH:mm:ss#")
      End Get
   End Property

   ''' <summary>
   ''' liefert einen SQL gerechten String fr einen numerischen Wert
   ''' </summary>
   ''' <param name="numWert">numerisches Object vom Typ Integer, Decimal, Double, String etc</param>
   Public ReadOnly Property strNum(ByVal numWert As Object) As String

      Get
         Dim s As String = "0"
         If numWert IsNot Nothing Then
            s = numWert.ToString
         End If
         s = s.Replace(",", ".")
         Return s
      End Get
   End Property
End Class
